@@ -183,7 +183,7 @@ gtk_offscreen_window_realize (GtkWidget *widget)
   window = gdk_window_new (gtk_widget_get_parent_window (widget),
                            &attributes, attributes_mask);
   gtk_widget_set_window (widget, window);
-  gdk_window_set_user_data (window, widget);
+  gtk_widget_register_window (widget, window);
 
   child = gtk_bin_get_child (bin);
   if (child)
@@ -282,7 +282,7 @@ gtk_offscreen_window_init (GtkOffscreenWindow *window)
  * Creates a toplevel container widget that is used to retrieve
  * snapshots of widgets without showing them on the screen.
  *
- * Return value: A pointer to a #GtkWidget
+ * Returns: A pointer to a #GtkWidget
  *
  * Since: 2.20
  */
