@@ -80,7 +80,7 @@ struct _GtkWindowClass
   void     (* activate_focus)   (GtkWindow *window);
   void     (* activate_default) (GtkWindow *window);
   void	   (* keys_changed)     (GtkWindow *window);
-  void	   (* enable_debugging) (GtkWindow *window,
+  gboolean (* enable_debugging) (GtkWindow *window,
                                  gboolean   toggle);
 
   /*< private >*/
